@@ -125,19 +125,25 @@ class OrderForm(ExtensibleModel):
             item.confirmed_count = sum(
                 [
                     order_item.count
-                    for order_item in OrderItem.objects.filter(order__form=self, item=item, order__confirmed=True)
+                    for order_item in OrderItem.objects.filter(
+                        order__form=self, item=item, order__confirmed=True
+                    )
                 ]
             )
             item.paid_count = sum(
                 [
                     order_item.count
-                    for order_item in OrderItem.objects.filter(order__form=self, item=item, order__paid=True)
+                    for order_item in OrderItem.objects.filter(
+                        order__form=self, item=item, order__paid=True
+                    )
                 ]
             )
             item.sent_count = sum(
                 [
                     order_item.count
-                    for order_item in OrderItem.objects.filter(order__form=self, item=item, order__sent=True)
+                    for order_item in OrderItem.objects.filter(
+                        order__form=self, item=item, order__sent=True
+                    )
                 ]
             )
             item.items_total = sum(
@@ -222,6 +228,22 @@ class Order(ExtensibleModel, TimeStampedModel):
             context={"order": self},
         )
 
+    def send_confirmation_reminder(self, request):
+        send_templated_mail(
+            template_name="confirmation_reminder",
+            from_email=self.form.email_sender,
+            recipient_list=self.email_recipients,
+            context={"order": self, "confirm_url": self.get_confirm_url(request)},
+        )
+
+    def send_pay_reminder(self, request):
+        send_templated_mail(
+            template_name="pay_reminder",
+            from_email=self.form.email_sender,
+            recipient_list=self.email_recipients,
+            context={"order": self},
+        )
+
     def __str__(self):
         return f"{self.form}: {self.full_name} [{self.created}]"
 
