@@ -3,9 +3,11 @@ from django.template.loader import render_to_string
 from django_tables2 import A, Column, LinkColumn, tables
 
 from aleksis.apps.order.models import Order
+from aleksis.core.util.tables import SelectColumn
 
 
 class OrderTable(tables.Table):
+    selected = SelectColumn()
     full_name = LinkColumn("show_order", args=[A("pk")])
     actions = Column(accessor="pk")
 
@@ -30,3 +32,4 @@ class OrderTable(tables.Table):
             "items_count",
             "total",
         )
+        sequence = ("selected", "...", "actions")
