@@ -1,13 +1,14 @@
-import os
 from tempfile import TemporaryDirectory
 from typing import Any, Dict
 
 from django.contrib import messages
+from django.core.exceptions import SuspiciousOperation
 from django.http import HttpRequest, HttpResponse
 from django.http.response import FileResponse, HttpResponseNotFound
 from django.shortcuts import get_object_or_404, redirect, render
 from django.urls import reverse_lazy
 from django.utils.translation import gettext as _
+from django.views.generic import FormView
 from django.views.generic.base import View
 from django.views.generic.detail import DetailView
 
@@ -17,17 +18,18 @@ from rules.contrib.views import PermissionRequiredMixin
 
 from aleksis.apps.order.filters import OrderFilter
 from aleksis.apps.order.pdf import generate_address_labels, generate_order_labels
-from aleksis.apps.order.settings import BASE_DIR
 from aleksis.apps.order.tables import OrderTable
-from aleksis.core.mixins import AdvancedEditView, AdvancedDeleteView
+from aleksis.core.mixins import AdvancedDeleteView, AdvancedEditView
 from aleksis.core.util.core_helpers import has_person, queryset_rules_filter
 from aleksis.core.util.pdf import render_pdf
 
 from .forms import (
     AccessForm,
     NotesForm,
+    OrderActionForm,
     OrderFormForm,
     OrderItemFormSet,
+    PickUpForm,
     ProcessingOptionForm,
     ShippingAddressForm,
 )
@@ -356,6 +358,7 @@ class OrderEditView(PermissionRequiredMixin, AdvancedEditView):
 
         return r
 
+
 class OrderDeleteView(PermissionRequiredMixin, AdvancedDeleteView):
     model = Order
     permission_required = "order.manage_order"
@@ -363,11 +366,13 @@ class OrderDeleteView(PermissionRequiredMixin, AdvancedDeleteView):
     success_message = _("The order has been deleted successfully.")
     success_url = reverse_lazy("list_orders")
 
+
 class OrderListView(PermissionRequiredMixin, SingleTableMixin, FilterView):
     table_class = OrderTable
     model = Order
     template_name = "order/list.html"
     permission_required = "order.view_orders"
+    table_pagination = {"per_page": 50}
 
     filterset_class = OrderFilter
 
@@ -377,20 +382,26 @@ class OrderListView(PermissionRequiredMixin, SingleTableMixin, FilterView):
         context["forms"] = queryset_rules_filter(
             self.request.user, OrderForm.objects.all(), "order.manage_orders_of_form"
         )
+        self.action_form = OrderActionForm(
+            self.request, self.request.POST or None, queryset=self.get_queryset()
+        )
+        context["action_form"] = self.action_form
         return context
 
     def post(self, request, *args, **kwargs):
         r = self.get(request, *args, **kwargs)
 
-        if request.POST.get("all-action"):
+        if "action" in self.request.POST and self.action_form.is_valid():
+            self.action_form.execute()
+
+        elif request.POST.get("all-action"):
             if request.POST.get("print"):
                 return render_pdf(request, "order/list_print.html", self.get_context_data())
             elif request.POST.get("packing-lists"):
                 return render_pdf(request, "order/packing_lists.html", self.get_context_data())
 
-
         # Action for a single object
-        if request.POST.get("single-action-pk"):
+        elif request.POST.get("single-action-pk"):
             order = get_object_or_404(Order, pk=request.POST.get("single-action-pk"))
 
             if request.POST.get("mark-as-paid"):
@@ -427,3 +438,54 @@ class OrderListView(PermissionRequiredMixin, SingleTableMixin, FilterView):
                     f = open(filename, "rb")
                     return FileResponse(f, filename="labels.pdf")
         return r
+
+
+class OrderPickUpFormView(PermissionRequiredMixin, FormView):
+    template_name = "order/pickup.html"
+    permission_required = "order.view_orders"
+    form_class = PickUpForm
+
+    def post(self, request, *args, **kwargs):
+        if request.POST.get("order_id_action"):
+            try:
+                order_id = int(request.POST["order_id_action"])
+            except ValueError:
+                raise SuspiciousOperation()
+            try:
+                order = Order.objects.get(pk=order_id)
+            except Order.DoesNotExist:
+                raise SuspiciousOperation()
+
+            if request.POST.get("abort"):
+                return self.get(request, *args, **kwargs)
+            elif request.POST.get("collected") and order.paid and not order.sent:
+                order.sent = True
+                order.save()
+                messages.success(request, _("The order was successfully marked as collected."))
+            elif request.POST.get("manually-paid-collected") and not order.paid and not order.sent:
+                order.sent = True
+                order.paid = True
+                order.notes += _("\nManually paid")
+                order.save()
+                messages.success(
+                    request, _("The order was successfully marked as manually paid and collected.")
+                )
+
+            elif request.POST.get("paid-collected") and not order.paid and not order.sent:
+                order.sent = True
+                order.paid = True
+                order.save()
+                messages.success(
+                    request, _("The order was successfully marked as normally paid and collected.")
+                )
+
+        return super().post(request, *args, **kwargs)
+
+    def form_valid(self, form) -> HttpResponse:
+        context = self.get_context_data()
+        order = form.cleaned_data["order_id"]
+        print(order)
+        context["order"] = order
+        context["form"] = PickUpForm()
+
+        return self.render_to_response(context)
